# Underwater Acoustic Analysis Toolbox
Welcome to the Underwater Acoustic Analysis toolbox for python.
This contains implementations of some analysis methods for underwater acoustics, with a focus on monitoring of noise for environmental impact.

- **Documentation**: https://underwater-acoustic-analysis.readthedocs.io
- **Source code**: https://github.com/CarlAndersson/underwater-acoustic-analysis

## Issues?
It you have issues, feel free to open an issue on the [issue tracker](https://github.com/CarlAndersson/underwater-acoustic-analysis/issues).
You can use this not only for bug reports, but also for general questions about how to use the code.

## Installation
The package is available on the [python package index](https://pypi.org/project/uwacan/). The easiest way is to install from there.
```
pip install uwacan
```
```
uv add uwacan
```
For Conda, refer to [this page](https://www.anaconda.com/docs/tools/working-with-conda/packages/pip-install) on how to install from PyPI.
For other python environment managers, refer to their specific documentation.
